Learn R Programming

EGAnet (version 0.9.0)

dimStability: Dimension Stability Statistics from bootEGA

Description

Based on the bootEGA results, this function computes the stability of dimensions. This is computed by assessing the proportion of items that replicate within the defined factor/dimension (see argument orig.wc) for each bootstrap. The mean of these proportions represent the dimensional stability for each dimension

Usage

dimStability(bootega.obj, orig.wc, item.stability = TRUE)

Arguments

bootega.obj

A bootEGA object

orig.wc

Numeric or character. A vector with community numbers or labels for each item. Typically uses community results (wc) from EGA

item.stability

Boolean. Should the item stability statistics be computed using [EGAnet]{itemStability}? Defaults to TRUE

Value

When argument item.stability = TRUE, returns a list containing:

dimensions

The dimensional stability of each dimension

items

The output from [EGAnet]{itemStability}

When argument item.stability = FALSE, returns a vector of the dimensional stability of each dimension

See Also

EGA to estimate the number of dimensions of an instrument using EGA and CFA to verify the fit of the structure suggested by EGA using confirmatory factor analysis.

Examples

Run this code
# NOT RUN {
# Load data
wmt <- wmt2[,7:24]

# }
# NOT RUN {
# Estimate EGA network
ega.wmt <- EGA(data = wmt, model = "glasso")

# Estimate dimension stability
boot.wmt <- bootEGA(data = wmt, n = 100, typicalStructure = TRUE,
plot.typicalStructure = TRUE, model = "glasso",
type = "parametric", ncores = 4)

# }
# NOT RUN {
# Estimate item stability statistics
dimStability(boot.wmt, orig.wc = ega.wmt$wc, item.stability = FALSE)

# }

Run the code above in your browser using DataLab