View source: R/dynEGA.ind.pop.R
| dynEGA.ind.pop | R Documentation |
dynEGAA wrapper function to estimate both intraindividiual
(level = "individual") and interindividual (level = "population")
structures using dynEGA
dynEGA.ind.pop(
data,
id = NULL,
n.embed = 5,
n.embed.optimize = FALSE,
tau = 1,
delta = 1,
use.derivatives = 1,
na.derivative = c("none", "kalman", "rowwise", "skipover"),
zero.jitter = 0.001,
corr = c("auto", "cor_auto", "pearson", "spearman"),
na.data = c("pairwise", "listwise"),
model = c("BGGM", "glasso", "TMFG"),
algorithm = c("leiden", "louvain", "walktrap"),
uni.method = c("expand", "LE", "louvain"),
ncores,
seed = NULL,
verbose = TRUE,
...
)
data |
Matrix or data frame. Participants and variable should be in long format such that row t represents observations for all variables at time point t for a participant. The next row, t + 1, represents the next measurement occasion for that same participant. The next participant's data should immediately follow, in the same pattern, after the previous participant
For groups, Arguments A measurement occasion variable is not necessary and should be removed from the data before proceeding with the analysis |
id |
Numeric or character (length = 1).
Number or name of the column identifying each individual.
Defaults to |
n.embed |
Numeric (length = 1 or more).
Defaults to If more than one value is provided, then the number of embeddings
will be optimized over using |
n.embed.optimize |
Boolean (length = 1).
If |
tau |
Numeric (length = 1).
Defaults to |
delta |
Numeric (length = 1).
Defaults to |
use.derivatives |
Numeric (length = 1).
Defaults to
Generally recommended to leave "as is" |
na.derivative |
Character (length = 1).
How should missing data in the embeddings be handled?
Available options (see Boker et al. (2018) in
|
zero.jitter |
Numeric (length = 1).
Small amount of Gaussian noise added to zero variance derivatives to prevent
estimation failures. For more than one variable, noise is generated
multivariate normal distribution to ensure orthogonal noise is added.
The jitter preserves the overall structure but avoids singular
covariance matrices during network estimation.
Defaults to |
corr |
Character (length = 1).
Method to compute correlations.
Defaults to
For other similarity measures, compute them first and input them
into |
na.data |
Character (length = 1).
How should missing data be handled?
Defaults to
|
model |
Character (length = 1).
Defaults to
|
algorithm |
Character or
|
uni.method |
Character (length = 1).
What unidimensionality method should be used?
Defaults to
|
ncores |
Numeric (length = 1).
Number of cores to use in computing results.
Defaults to If you're unsure how many cores your computer has,
then type: |
seed |
Numeric (length = 1).
Defaults to |
verbose |
Boolean (length = 1).
Should progress be displayed?
Defaults to |
... |
Additional arguments to be passed on to
|
Same output as EGAnet{dynEGA} returning list
objects for level = "individual" and level = "population"
Hudson Golino <hfg9s at virginia.edu>
plot.EGAnet for plot usage in EGAnet
# Obtain data
sim.dynEGA <- sim.dynEGA # bypasses CRAN checks
## Not run:
# Dynamic EGA individual and population structure
dyn.ega1 <- dynEGA.ind.pop(
data = sim.dynEGA, n.embed = 5, tau = 1,
delta = 1, id = 25, use.derivatives = 1,
ncores = 2, corr = "pearson"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.