View source: R/itemDiagnostics.R
| itemDiagnostics | R Documentation |
Computes item diagnostics to determine whether there exist several
potential psychometric issues that affect itemStability.
These issues include local dependence (using UVA),
minor dimensions (using cosine on the stability patterns),
multidimensional items (using net.loads), and
items with low loadings (using net.loads)
itemDiagnostics(data, ...)
data |
Matrix or data frame. Should consist only of variables to be used in the analysis |
... |
Additional arguments to pass on to
|
Returns a list containing:
diagnostics |
A data frame containing the diagnostics of low item stabilities
(see |
boot |
Output from |
uva |
Output from |
minor |
A list containing suggested items to |
loadings |
Output from |
suggested |
Variables that are suggested to be retained to increase item stability |
Alexander P. Christensen <alexpaulchristensen@gmail.com>, Hudson Golino <hfg9s at virginia.edu>, and Luis Eduardo Garrido <garrido.luiseduardo@gmail.com>
# Load data
wmt <- wmt2[,7:24]
## Not run:
# Obtain diagnostics
diagnostics <- itemDiagnostics(wmt, ncores = 2)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.