Learn R Programming

EGAnet (version 0.9.0)

node.redundant: Detects Redundant Nodes in a Network

Description

Identifies redundant nodes in the network based on several measures. Computes the weighted topological overlap between each node and every other node in the network. The weighted topological overlap is implemented using the method from Nowick et al. (2009; see references) and the function wTO from the wTO package.

Usage

node.redundant(
  data,
  sig,
  type = c("wTO", "pcor", "thresh"),
  method = c("alpha", "bonferroni", "FDR", "adapt")
)

Arguments

data

Matrix or data frame

sig

Numeric. p-value for significance of overlap (defaults to .05). If more than 200 connections, then fdrtool is used to correct for false positives. In these instances, sig sets the q-value for significance of overlap (defaults to .10)

type

Character. Computes weighted topological overlap ("wTO" using EBICglasso), partial correlations ("pcor"), or thresholding based on a certain level of partial correlations ("thresh"). type = "thresh" will use the argument "sig" to input the desired threshold (defaults to sig = .20).

method

Character. Computes significance using the standard p-value ("alpha"), bonferroni corrected p-value ("bonferroni"), false-discovery rate corrected p-value ("FDR"), or adaptive alpha p-value (adapt.a). Defaults to "alpha"

Value

Returns a list:

redundant

Vectors nested within the list corresponding to redundant nodes with the name of object in the list

data

Returns original data

weights

Returns weights determine by weighted topological overlap or partial correlations

network

The network compute by EBICglasso

References

#wTO Nowick, K., Gernat, T., Almaas, E., & Stubbs, L. (2009). Differences in human and chimpanzee gene expression patterns define an evolving network of transcription factors in brain. Proceedings of the National Academy of Sciences, 106, 22358-22363.

Examples

Run this code
# NOT RUN {
# obtain SAPA items
items <- psychTools::spi[,-c(1:10)]

# }
# NOT RUN {
# weighted topological overlap
redund <- node.redundant(items, type = "wTO", method = "adapt")

# partial correlation
redund <- node.redundant(items, type = "pcor", method = "adapt")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab