View source: R/oldsimEGM.R View source: R/simEGM.R
| simEGM | R Documentation |
EGM)Function to simulate data based on EGM
simEGM(
communities,
variables,
loadings,
cross.loadings = 0.01,
correlations,
sample.size,
quality = c("acceptable", "robust"),
max.iterations = 100
)
communities |
Numeric (length = 1). Number of communities to generate |
variables |
Numeric vector (length = 1 or |
loadings |
Numeric (length = 1, Uses |
cross.loadings |
Numeric (length = 1).
Standard deviation of a normal distribution with a mean of zero ( |
correlations |
Numeric (length = 1 or
|
sample.size |
Numeric (length = 1). Number of observations to generate |
quality |
Character (length = 1). Quality metrics related to the alignment of the correlations implied by the loadings and network are computed with certain standards in place to accept a solution. These metrics include:
Defaults to |
max.iterations |
Numeric (length = 1).
Number of iterations to attempt to get convergence before erroring out.
Defaults to |
Hudson F. Golino <hfg9s at virginia.edu> and Alexander P. Christensen <alexpaulchristensen@gmail.com>
simulated <- simEGM(
communities = 2, variables = 6,
loadings = 0.35, # use network loading sizes
correlations = 0.30, sample.size = 1000
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.