Learn R Programming

EGAnet (version 0.9.0)

net.scores: Network Scores

Description

This function computes network scores for factor analysis models. Network scores are computed based on each node's strength within each community (i.e., factor) in the network. These values are used as network "factor loadings" for the weights of each item. Notably, network analysis allows nodes to load onto more than one factor. These loadings are considered in the factor scores. In addition, if the construct is a hierarchy (e.g., personality questionnaire; items in facet scales in a trait domain), then an overall score can be computed (see argument general). These overall scores are computed using comm.close as weights, which are roughly similar to general factor loadings in a CFA model (see Christensen, Golino, & Silvia, 2019). The score estimates are roughly equivalent to the Maximum Likelihood method in lavaan's cfa function. An important difference is that the network scores account for cross-loadings in their estimation of scores.

Usage

net.scores(data, A, wc, global = TRUE, type = c("sumscore", "latent"), ...)

Arguments

data

Matrix or data frame. Must be a dataset

A

Matrix, data frame, or EGA object. An adjacency matrix of network data

wc

Numeric. A vector of community assignments. Not necessary if an EGA object is input for argument A

global

Boolean. Should general network loadings be computed in scores? Defaults to TRUE. If there is more than one dimension and there is theoretically one global dimension, then general loadings of the dimensions onto the global dimension can be included in the weighted scores. For the type of weights (e.g., sum score or latent), see the type argument

type

Character. Should network scores parallel sum scores or latent variable scores? Defaults to "latent". Argument type sets the community centrality measure that is used when computing the network loadings for multiple factors. Simulations have shown that comm.eigen computes weights that are closer to sum scores while comm.close computes weights that are closer to latent variable scores. See Christensen, Golino, and Silvia (2019) for more details

...

Additional arguments for cluster_walktrap and louvain community detection algorithms

Value

Returns a list containing:

unstd.scores

The unstandardized network scores for each participant and community (including the overall score)

std.scores

The standardized network scores for each participant and community (including the overall score)

commCor

Partial correlations between the specified or identified communities

loads

Standardized network loadings for each item in each dimension (computed using net.loads)

Details

For more details, type vignette("Network_Scores")

References

Christensen, A. P. (2018). NetworkToolbox: Methods and measures for brain, cognitive, and psychometric network analysis in R. The R Journal, 10, 422-439. doi: 10.32614/RJ-2018-065

Christensen, A. P., Golino, H. F., & Silvia, P. J. (2019). A psychometric network perspective on the measurement and assessment of personality traits. PsyArXiv. doi: 10.31234/osf.io/ktejp

Examples

Run this code
# NOT RUN {
# Load data
wmt <- wmt2[,7:24]

# }
# NOT RUN {
 # Estimate EGA
 ega.wmt <- EGA(wmt)
# }
# NOT RUN {
 # Network scores
 net.scores(data = wmt, A = ega.wmt)

# }

Run the code above in your browser using DataLab